Crate multi_base

Crate multi_base 

multibase

Implementation of multibase in Rust.

Re-exports

pub use self::encoded::EncodedString;

Modules

encoded
Validated multibase-encoded strings.

Enums

Base
List of types currently supported in the multibase spec.
Error
Error types for multibase operations.

Functions

decode
Decode the base string.
decode_into
Decode the base string, writing the result into an existing buffer.
encode
Encode with the given byte slice to base string.
encode_into
Encode with the given byte slice to base string, writing into an existing buffer.
encode_to_validated
Encode with the given byte slice and return a validated EncodedString.
parse_encoded
Parse a multibase string into a validated EncodedString.

Type Aliases

Result
Type alias to use this library’s Error type in a Result.