Re-exports
pub use self::encoded::EncodedString;
Modules
- encoded
- Validated multibase-encoded strings.
Enums
- Base
- List of types currently supported in the multibase spec.
- Error
- Error types for multibase operations.
Functions
- decode
- Decode the base string.
- decode_
into - Decode the base string, writing the result into an existing buffer.
- encode
- Encode with the given byte slice to base string.
- encode_
into - Encode with the given byte slice to base string, writing into an existing buffer.
- encode_
to_ validated - Encode with the given byte slice and return a validated
EncodedString. - parse_
encoded - Parse a multibase string into a validated
EncodedString.